#[repr(C)]pub struct DeviceRegisterReadRequest {
pub address: u16,
pub size_bytes: u32,
}Fields
address: u16size_bytes: u32Trait Implementations
Sourceimpl Clone for DeviceRegisterReadRequest
impl Clone for DeviceRegisterReadRequest
Sourcefn clone(&self) -> DeviceRegisterReadRequest
fn clone(&self) -> DeviceRegisterReadRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRegisterReadRequest
impl Debug for DeviceRegisterReadRequest
Sourceimpl<D: ResourceDialect> Decode<DeviceRegisterReadRequest, D> for DeviceRegisterReadRequest
impl<D: ResourceDialect> Decode<DeviceRegisterReadRequest, D> for DeviceRegisterReadRequest
Sourceimpl<D: ResourceDialect> Encode<DeviceRegisterReadRequest, D> for &DeviceRegisterReadRequest
impl<D: ResourceDialect> Encode<DeviceRegisterReadRequest, D> for &DeviceRegisterReadRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u16, D>, T1: Encode<u32, D>> Encode<DeviceRegisterReadRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<u16, D>, T1: Encode<u32, D>> Encode<DeviceRegisterReadRequest, D> for (T0, T1)
Sourceimpl Hash for DeviceRegisterReadRequest
impl Hash for DeviceRegisterReadRequest
Sourceimpl Ord for DeviceRegisterReadRequest
impl Ord for DeviceRegisterReadRequest
Sourcefn cmp(&self, other: &DeviceRegisterReadRequest) -> Ordering
fn cmp(&self, other: &DeviceRegisterReadRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRegisterReadRequest
impl PartialEq for DeviceRegisterReadRequest
Sourcefn eq(&self, other: &DeviceRegisterReadRequest) -> bool
fn eq(&self, other: &DeviceRegisterReadRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRegisterReadRequest
impl PartialOrd for DeviceRegisterReadRequest
Sourceimpl TypeMarker for DeviceRegisterReadRequest
impl TypeMarker for DeviceRegisterReadRequest
Sourcetype Owned = DeviceRegisterReadRequest
type Owned = DeviceRegisterReadRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceRegisterReadRequest
impl ValueTypeMarker for DeviceRegisterReadRequest
Sourcetype Borrowed<'a> = &'a DeviceRegisterReadRequest
type Borrowed<'a> = &'a DeviceRegisterReadRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for DeviceRegisterReadRequest
impl Eq for DeviceRegisterReadRequest
impl Persistable for DeviceRegisterReadRequest
impl StructuralPartialEq for DeviceRegisterReadRequest