pub struct DeviceRegisterReadResponse {
pub data: Vec<u8>,
}Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceRegisterReadResponse
impl Clone for DeviceRegisterReadResponse
Sourcefn clone(&self) -> DeviceRegisterReadResponse
fn clone(&self) -> DeviceRegisterReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRegisterReadResponse
impl Debug for DeviceRegisterReadResponse
Sourceimpl<D: ResourceDialect> Decode<DeviceRegisterReadResponse, D> for DeviceRegisterReadResponse
impl<D: ResourceDialect> Decode<DeviceRegisterReadResponse, D> for DeviceRegisterReadResponse
Sourceimpl<D: ResourceDialect> Encode<DeviceRegisterReadResponse, D> for &DeviceRegisterReadResponse
impl<D: ResourceDialect> Encode<DeviceRegisterReadResponse, D> for &DeviceRegisterReadResponse
Sourceimpl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<DeviceRegisterReadResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<DeviceRegisterReadResponse, D> for (T0,)
Sourceimpl Hash for DeviceRegisterReadResponse
impl Hash for DeviceRegisterReadResponse
Sourceimpl Ord for DeviceRegisterReadResponse
impl Ord for DeviceRegisterReadResponse
Sourcefn cmp(&self, other: &DeviceRegisterReadResponse) -> Ordering
fn cmp(&self, other: &DeviceRegisterReadResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRegisterReadResponse
impl PartialEq for DeviceRegisterReadResponse
Sourcefn eq(&self, other: &DeviceRegisterReadResponse) -> bool
fn eq(&self, other: &DeviceRegisterReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRegisterReadResponse
impl PartialOrd for DeviceRegisterReadResponse
Sourceimpl TypeMarker for DeviceRegisterReadResponse
impl TypeMarker for DeviceRegisterReadResponse
Sourcetype Owned = DeviceRegisterReadResponse
type Owned = DeviceRegisterReadResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceRegisterReadResponse
impl ValueTypeMarker for DeviceRegisterReadResponse
Sourcetype Borrowed<'a> = &'a DeviceRegisterReadResponse
type Borrowed<'a> = &'a DeviceRegisterReadResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for DeviceRegisterReadResponse
impl Persistable for DeviceRegisterReadResponse
impl StructuralPartialEq for DeviceRegisterReadResponse