pub struct DeviceRegisterWriteRequest {
pub address: u16,
pub data: Vec<u8>,
}Fields
address: u16data: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceRegisterWriteRequest
impl Clone for DeviceRegisterWriteRequest
Sourcefn clone(&self) -> DeviceRegisterWriteRequest
fn clone(&self) -> DeviceRegisterWriteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceRegisterWriteRequest
impl Debug for DeviceRegisterWriteRequest
Sourceimpl<D: ResourceDialect> Decode<DeviceRegisterWriteRequest, D> for DeviceRegisterWriteRequest
impl<D: ResourceDialect> Decode<DeviceRegisterWriteRequest, D> for DeviceRegisterWriteRequest
Sourceimpl<D: ResourceDialect> Encode<DeviceRegisterWriteRequest, D> for &DeviceRegisterWriteRequest
impl<D: ResourceDialect> Encode<DeviceRegisterWriteRequest, D> for &DeviceRegisterWriteRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u16, D>, T1: Encode<UnboundedVector<u8>, D>> Encode<DeviceRegisterWriteRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<u16, D>, T1: Encode<UnboundedVector<u8>, D>> Encode<DeviceRegisterWriteRequest, D> for (T0, T1)
Sourceimpl Hash for DeviceRegisterWriteRequest
impl Hash for DeviceRegisterWriteRequest
Sourceimpl Ord for DeviceRegisterWriteRequest
impl Ord for DeviceRegisterWriteRequest
Sourcefn cmp(&self, other: &DeviceRegisterWriteRequest) -> Ordering
fn cmp(&self, other: &DeviceRegisterWriteRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceRegisterWriteRequest
impl PartialEq for DeviceRegisterWriteRequest
Sourcefn eq(&self, other: &DeviceRegisterWriteRequest) -> bool
fn eq(&self, other: &DeviceRegisterWriteRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceRegisterWriteRequest
impl PartialOrd for DeviceRegisterWriteRequest
Sourceimpl TypeMarker for DeviceRegisterWriteRequest
impl TypeMarker for DeviceRegisterWriteRequest
Sourcetype Owned = DeviceRegisterWriteRequest
type Owned = DeviceRegisterWriteRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceRegisterWriteRequest
impl ValueTypeMarker for DeviceRegisterWriteRequest
Sourcetype Borrowed<'a> = &'a DeviceRegisterWriteRequest
type Borrowed<'a> = &'a DeviceRegisterWriteRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for DeviceRegisterWriteRequest
impl Persistable for DeviceRegisterWriteRequest
impl StructuralPartialEq for DeviceRegisterWriteRequest