#[repr(C)]pub struct Register8 {
pub address: u8,
pub data: u8,
}Expand description
A single register read from or written to with an SPMI command that uses an 8-bit address.
Fields
address: u8data: u8Trait Implementations
Sourceimpl<D: ResourceDialect> Decode<Register8, D> for Register8
impl<D: ResourceDialect> Decode<Register8, D> for Register8
Sourceimpl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>> Encode<Register8, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>> Encode<Register8, D> for (T0, T1)
Sourceimpl Ord for Register8
impl Ord for Register8
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Register8
impl PartialOrd for Register8
Sourceimpl TypeMarker for Register8
impl TypeMarker for Register8
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Register8
impl ValueTypeMarker for Register8
impl Copy for Register8
impl Eq for Register8
impl Persistable for Register8
impl StructuralPartialEq for Register8